class URL(object):
    SANDBOX_BASE_URL = 'https://stg-api.sandbox.paypay.ne.jp/v2'
    PRODUCTION_BASE_URL = 'https://api.paypay.ne.jp/v2'
    CODE = "/codes"
    PAYMENT = "/payments"
    ACCOUNT_LINK = "/qr/sessions"
